@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016 Google Inc.
+# Copyright 2016 Google Inc. and Yelp
+# Copyright 2017 Yelp
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -917,10 +918,14 @@ class DataprocJobRunner(MRJobRunner):
             out.append(line + '\n')
 
         # shebang
-        sh_bin = self._opts['sh_bin']
+        sh_bin = self._sh_bin()
         if not sh_bin[0].startswith('/'):
             sh_bin = ['/usr/bin/env'] + sh_bin
         writeln('#!' + cmd_line(sh_bin))
+
+        # unused hook for 'set -e', etc. (see #1549)
+        for cmd in self._sh_pre_commands():
+            writeln(cmd)
         writeln()
 
         # store $PWD
