@@ -604,13 +604,15 @@ _RUNNER_OPTS = dict(
             )),
         ],
     ),
-    emr_applications=dict(
+    applications=dict(
         cloud_role='launch',
         combiner=combine_lists,
+        deprecated_aliases=['emr_applications'],
         runners=['emr'],
         switches=[
-            (['--emr-application'], dict(
+            (['--application'], dict(
                 action='append',
+                deprecated_aliases=['--emr-application'],
                 help=('Additional applications to run on 4.x AMIs (e.g.'
                       ' Ganglia, Mahout, Spark)'),
             )),
@@ -1259,6 +1261,17 @@ _RUNNER_OPTS = dict(
             )),
         ],
     ),
+    task_python_bin=dict(
+        combiner=combine_cmds,
+        switches=[
+            (['--task-python-bin'], dict(
+                help=('Name/path of alternate python command to use to'
+                      " run tasks (e.g. mappers); doesn't affect setup"
+                      ' wrapper scripts. Defaults to'
+                      ' current Python interpreter.'),
+            )),
+        ],
+    ),
     upload_archives=dict(
         combiner=combine_path_lists,
         switches=[
