@@ -781,10 +781,10 @@ class MRJobRunner(object):
         if steps:
             return (self._opts['steps_interpreter'] or
                     self._opts['interpreter'] or
-                    self._python_bin(steps=True))
+                    self._steps_python_bin())
         else:
             return (self._opts['interpreter'] or
-                    self._python_bin())
+                    self._task_python_bin())
 
     def _executable(self, steps=False):
         if steps:
@@ -793,13 +793,31 @@ class MRJobRunner(object):
             return self._interpreter() + [
                 self._working_dir_mgr.name('file', self._script_path)]
 
-    def _python_bin(self, steps=False):
-        if steps:
-            return (self._opts['steps_python_bin'] or
-                    self._default_python_bin(local=True))
-        else:
-            return (self._opts['python_bin'] or
-                    self._default_python_bin())
+    def _python_bin(self):
+        """Python binary used for everything other than invoking the job.
+        For invoking jobs with ``--steps``, see :py:meth:`_steps_python_bin`,
+        and for everything else (e.g. ``--mapper``, ``--spark``), see
+        :py:meth:`_task_python_bin`, which defaults to this method if
+        :mrjob-opt:`task_python_bin` isn't set.
+
+        Other ways mrjob uses Python:
+         * file locking in setup wrapper scripts
+         * finding site-packages dir to bootstrap mrjob on clusters
+         * invoking ``cat.py`` in local mode
+         * the Python binary for Spark (``$PYSPARK_PYTHON``)
+        """
+        return self._opts['python_bin'] or self._default_python_bin()
+
+    def _steps_python_bin(self):
+        """Python binary used to invoke job with ``--steps``"""
+        return (self._opts['steps_python_bin'] or
+                self._default_python_bin(local=True))
+
+    def _task_python_bin(self):
+        """Python binary used to invoke job with ``--mapper``,
+        ``--reducer``, ``--spark``, etc."""
+        return (self._opts['task_python_bin'] or
+                self._python_bin())
 
     def _default_python_bin(self, local=False):
         """The default python command. If local is true, try to use
@@ -824,7 +842,7 @@ class MRJobRunner(object):
         ] + self._mr_job_extra_args()
 
         if self._setup_wrapper_script_path:
-            return (self._opts['sh_bin'] +
+            return (self._sh_bin() +
                     [self._working_dir_mgr.name(
                         'file', self._setup_wrapper_script_path)] +
                     args)
@@ -873,8 +891,11 @@ class MRJobRunner(object):
     def _sh_wrap(self, cmd_str):
         """Wrap command in sh -c '...' to allow for pipes, etc.
         Use *sh_bin* option."""
+        # prepend set -e etc.
+        cmd_str = '; '.join(self._sh_pre_commands() + [cmd_str])
+
         return "%s -c '%s'" % (
-            cmd_line(self._opts['sh_bin']),
+            cmd_line(self._sh_bin()),
             cmd_str.replace("'", "'\\''"))
 
     def _mr_job_extra_args(self, local=False):
@@ -919,6 +940,19 @@ class MRJobRunner(object):
         else:
             return []
 
+    def _sh_bin(self):
+        """The sh binary and any arguments, as a list. Override this
+        if, for example, a runner needs different default values
+        depending on circumstances (see :py:class:`~mrjob.emr.EMRJobRunner`).
+        """
+        return self._opts['sh_bin']
+
+    def _sh_pre_commands(self):
+        """A list of lines to put at the very start of any sh script
+        (e.g. ``set -e`` when ``sh -e`` wont work, see #1549)
+        """
+        return []
+
     def _create_setup_wrapper_script(
             self, dest='setup-wrapper.sh', local=False):
         """Create the wrapper script, and write it into our local temp
@@ -1043,6 +1077,13 @@ class MRJobRunner(object):
         def writeln(line=''):
             out.append(line + '\n')
 
+        # hook for 'set -e', etc.
+        pre_commands = self._sh_pre_commands()
+        if pre_commands:
+            for cmd in pre_commands:
+                writeln(cmd)
+            writeln()
+
         # we're always going to execute this script as an argument to
         # sh, so there's no need to add a shebang (e.g. #!/bin/sh)
 
